aboutsummaryrefslogtreecommitdiff
path: root/ares/ares_parse_srv_reply.c
diff options
context:
space:
mode:
authorDaniel Stenberg <daniel@haxx.se>2009-10-29 08:50:34 +0000
committerDaniel Stenberg <daniel@haxx.se>2009-10-29 08:50:34 +0000
commit982e655c077ea3f8f0f198aa6acf99da581f656e (patch)
treece392c5825b5089fdd10f71c119adcc34b04e39d /ares/ares_parse_srv_reply.c
parent308497ffc636cb863c8d4a99f1c4cf7530b01f55 (diff)
use 'ares_srv_reply' for proper name-spacing
Diffstat (limited to 'ares/ares_parse_srv_reply.c')
-rw-r--r--ares/ares_parse_srv_reply.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/ares/ares_parse_srv_reply.c b/ares/ares_parse_srv_reply.c
index c26d59f2a..b0e15eb0f 100644
--- a/ares/ares_parse_srv_reply.c
+++ b/ares/ares_parse_srv_reply.c
@@ -54,14 +54,14 @@
int
ares_parse_srv_reply (const unsigned char *abuf, int alen,
- struct srv_reply **srv_out, int *nsrvreply)
+ struct ares_srv_reply **srv_out, int *nsrvreply)
{
unsigned int qdcount, ancount;
const unsigned char *aptr;
int status, i, rr_type, rr_class, rr_len;
long len;
char *hostname = NULL, *rr_name = NULL;
- struct srv_reply *srv = NULL;
+ struct ares_srv_reply *srv = NULL;
/* Set *srv_out to NULL for all failure cases. */
if (srv_out)
@@ -95,8 +95,8 @@ ares_parse_srv_reply (const unsigned char *abuf, int alen,
}
aptr += len + QFIXEDSZ;
- /* Allocate srv_reply array; ancount gives an upper bound */
- srv = malloc ((ancount) * sizeof (struct srv_reply));
+ /* Allocate ares_srv_reply array; ancount gives an upper bound */
+ srv = malloc ((ancount) * sizeof (struct ares_srv_reply));
if (!srv)
{
free (hostname);